@@ -57,7 +57,7 @@ class SimpleTest(unittest.TestCase):
     def tearDown(self):
         self.lines.drop()
         self.blocks.drop()
-        
+
     def save(self, ob):
         self.session.save(ob)
         self.session.flush()
@@ -81,7 +81,7 @@ class SimpleTest(unittest.TestCase):
         self.assertEquals(b.lines, 1)
         self.assertEquals(b.lastline, l.id)
         self.assertEquals(b.length, 10)
-        
+
     def testAddMoreLines(self):
         b = self.Block()
         b.lines = 0
@@ -95,7 +95,7 @@ class SimpleTest(unittest.TestCase):
         self.session.refresh(b)
         self.assertEquals(b.lastline, l.id)
         self.assertEquals(b.length, 45)
-    
+
     def testUpdate(self):
         b = self.Block()
         b.lines = 0
@@ -249,7 +249,7 @@ class SimpleTest(unittest.TestCase):
         self.assertEquals(b2.length, 36)
         self.assertEquals(b1.lastline, last2.id)
         self.assertNotEquals(b2.lastline, last2.id)
-        
+
 
 class ComplexTest(unittest.TestCase):
     def __init__(self, arg):
@@ -308,7 +308,7 @@ class ComplexTest(unittest.TestCase):
         self.lines.drop()
         self.blocks.drop()
         self.users.drop()
-        
+
     def save(self, ob):
         self.session.save(ob)
         self.session.flush()
@@ -482,7 +482,7 @@ class RelationsTest(unittest.TestCase):
         self.lines.drop()
         self.blocks.drop()
         self.users.drop()
-        
+
     def save(self, ob):
         self.session.save(ob)
         self.session.flush()
@@ -591,7 +591,7 @@ class RelationsTest(unittest.TestCase):
         self.assertEquals(m.blocks, 2)
         self.assertEquals(j.lines, 13)
         self.assertEquals(m.lines, 7)
-        
+
 class TestBigValue(unittest.TestCase):
     def __init__(self, arg):
         self.aggregator_class = a.Quick
@@ -627,7 +627,7 @@ class TestBigValue(unittest.TestCase):
     def tearDown(self):
         self.lines.drop()
         self.blocks.drop()
-        
+
     def save(self, ob):
         self.session.save(ob)
         self.session.flush()
@@ -692,11 +692,11 @@ class TestUpdates(unittest.TestCase):
     def tearDown(self):
         self.lines.drop()
         self.blocks.drop()
-        
+
     def save(self, ob):
         self.session.save(ob)
         self.session.flush()
-    
+
     def testAddValue(self):
         b = self.Block()
         b.lines = 0
@@ -728,32 +728,66 @@ class TestUpdates(unittest.TestCase):
         self.session.refresh(b)
         self.assertEquals(b.minlength, 0)
         self.assertEquals(b.maxlength, 9)
-        
 
-class SimpleTest2(SimpleTest):
+class InheritanceTest(SimpleTest):
+    def setUp(self):
+        meta = self.meta = MetaData(bind=dburl)
+        self.session = create_session()
+        blocks = Table('blocks', meta,
+            Column('id', Integer, primary_key=True, autoincrement=True),
+            Column('lines', Integer),
+            Column('lastline', Integer),
+            Column('length', Integer),
+            )
+        lines = Table('lines', meta,
+            Column('id', Integer, primary_key=True, autoincrement=True),
+            Column('block', Integer, ForeignKey(blocks.c.id)),
+            Column('length', Integer, default=10),
+            Column('language', String(2))
+            )
+        class Block(object):
+            pass
+        class Line(object):
+            pass
+        class LineEn(Line):
+            pass
+        self.Block = Block
+        self.Line = LineEn
+        self.blocks = blocks
+        self.lines = lines
+        blocks.create()
+        lines.create()
+        mapper(Block, blocks)
+        line_mapper = mapper(Line, lines, polymorphic_on=lines.c.language)
+        mapper(LineEn, inherits=line_mapper, polymorphic_identity='en',
+            extension=self.aggregator_class(
+                a.Max(blocks.c.lastline, lines.c.id),
+                a.Count(blocks.c.lines),
+                a.Sum(blocks.c.length, lines.c.length),
+            ))
+
+class TestAccurate(unittest.TestCase):
     def __init__(self, arg):
         self.aggregator_class = a.Accurate
-        return unittest.TestCase.__init__(self, arg)
+        return super(TestAccurate, self).__init__(arg)
 
-class ComplexTest2(ComplexTest):
-    def __init__(self, arg):
-        self.aggregator_class = a.Accurate
-        return unittest.TestCase.__init__(self, arg)
+class SimpleTest2(SimpleTest,TestAccurate):
+    pass
 
-class RelationsTest2(ComplexTest):
-    def __init__(self, arg):
-        self.aggregator_class = a.Accurate
-        return unittest.TestCase.__init__(self, arg)
+class ComplexTest2(ComplexTest,TestAccurate):
+    pass
 
-class TestBigValue2(TestBigValue):
-    def __init__(self, arg):
-        self.aggregator_class = a.Accurate
-        return unittest.TestCase.__init__(self, arg)
+class RelationsTest2(RelationsTest, TestAccurate):
+    pass
 
-class TestUpdates2(TestUpdates):
-    def __init__(self, arg):
-        self.aggregator_class = a.Accurate
-        return unittest.TestCase.__init__(self, arg)
+class TestBigValue2(TestBigValue, TestAccurate):
+    pass
+
+class TestUpdates2(TestUpdates, TestAccurate):
+    pass
+
+class InheritanceTest2(InheritanceTest, TestAccurate):
+    pass
 
 if __name__ == '__main__':
     unittest.main()
